@@ -1,8 +1,12 @@
 #include <R.h>
 #include <Rinternals.h>
-#include <stdlib.h>
+#include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
+/* FIXME:
+   Check these declarations against the C/Fortran source code.
+*/
+
 /* .Call calls */
 extern SEXP _RStoolbox_classQA(SEXP, SEXP);
 extern SEXP _RStoolbox_entropyCpp(SEXP);
